@@ -25,7 +25,7 @@ def list_files_with_extension(ext, rep, recursive=True) -> List[str]:
 
 def read_file_drop_comments(path: str) -> List[str]:
     lines = []
-    with open(path, 'r') as f:
+    with open(path, 'r', encoding='utf-8') as f:
         for l in f.readlines():
             l = l.strip()
             if l and not l.startswith('#'):
